==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <source>%1 First Start</source>
        <translation>%1 prvi začetek</translation>
    </message>
    <message>
        <location line="+185"/>
        <source>Black</source>
        <translation>Črno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Belo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Language:</source>
        <translation>Jezik:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translation>Dobrodošli v %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translation>Izberite nastavitve za nove risbe. Vse te nastavitve, lahko kasneje spremenite v nastavitvah programa.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translation>Enota:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translation>Privzeta velikost papirja:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translation>Decimalna pika:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translation>Barva ozadja:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/FirstStart/ts/FirstStart_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>FirstStart</name>
    <message>
        <location filename="../FirstStart.js" line="+35"/>
        <location line="+216"/>
        <source>%1 First Start</source>
        <translation>%1 prvi začetek</translation>
    </message>
    <message>
        <location line="-5"/>
        <source>Black</source>
        <translation>Črno</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Belo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Language:</source>
        <translation>Jezik:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welcome to %1</source>
        <translation>Dobrodošli v %1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Please choose the settings used for new drawings. All these settings can be changed later in the Preference Dialog.</source>
        <translation>Izberite nastavitve za nove risbe. Vse te nastavitve, lahko kasneje spremenite v nastavitvah programa.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Unit:</source>
        <translation>Enota:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default Paper Size:</source>
        <translation>Privzeta velikost papirja:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal Point:</source>
        <translation>Decimalna pika:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background Color:</source>
        <translation>Barva ozadja:</translation>
    </message>
</context>
</TS>
